import requests

def upload_file(file_name, signed_url):
    with open(file_name, 'rb') as f:
        # to add progress here
        requests.post(signed_url['url'], data=signed_url['fields'], files=f)





class Config:
    """
    Create a config using this class
    Attributes
    ----------
    config : dict -> {
        clientId: '',
        api_key: '',
        projectId: '',
        solutionId: ''
    }
    """

    mandatory_config_fields = ['clientId', 'key', 'api', 'projectId', 'solutionId', 'moduleId']
    def validate_config(self):
        for mandatory_config in self.mandatory_config_fields:
            if mandatory_config not in self.config:
                raise Exception(f"{mandatory_config} field is missing from the config")
    def __init__(self, config):
        self.config = config
        self.validate_config()
        self.session = {
            'config': self.config
        }





from guardian_audit import GuardianAudit
from chatgpt_wrapper import GPTWrapper

def audit_toxicity(prompts):
    toxicity_messages = []
    for prompt in prompts['toxicity']["toxicity_prompts"]:
        full_prompt = f"complete the following sentence: {prompt}"
        completion = gpt.complete(full_prompt)["choices"][0]["text"]
        processed_prompt = full_prompt.split(":")[1]
        processed_prompt = processed_prompt + completion

        toxicity_messages.append({
            "prompt": prompt,
            "response": processed_prompt.strip()
        })
    return toxicity_messages

def audit_stereotype(prompts):
    stereotype_messages = []
    # audit ChatGPT
    for prompt in prompts['stereotype']["stereotype_prompts"]:
        full_prompt = prompt
        completion = gpt.complete(full_prompt)["choices"][0]["text"]
        processed_prompt = full_prompt.split(":")[1]
        processed_prompt = processed_prompt + completion

        stereotype_messages.append({
            "prompt": prompt,
            "response": processed_prompt.strip()
        })
    return stereotype_messages

def audit_emotion(prompts):
    emotion_messages = []
    for prompt in prompts['emotion']:
        completion = gpt.complete(prompt)["choices"][0]["text"]
        emotion_messages.append({
            "prompt": prompt,
            "response": completion.strip()
        })
    return emotion_messages

def audit_sentiment(prompts):
    sentiment_messages = []
    for prompt in prompts['sentiment']:
        completion = gpt.complete(prompt)["choices"][0]["text"]
        sentiment_messages.append({
            "prompt": prompt,
            "response": completion.strip()
        })
    return sentiment_messages

config = {
    "tenant_id": "HolisticAI-58jnt",
    "apikey": "YmIzMGQzZDAtMTY0Yi00Mjk2LWIxY2UtMTJhMWRmMjhhNTI3",
    "audit_id": "3c5c137c-efb6-4b50-b52f-32328c6d472e"
}

audit = GuardianAudit(config)

gpt = GPTWrapper()
audit_prompts = audit.load_prompts()


to_audit = {
    'stereotype': audit_stereotype(audit_prompts),
    'toxicity': audit_toxicity(audit_prompts),
    'emotion': audit_emotion(audit_prompts),
    'sentiment': audit_sentiment(audit_prompts)
}
# send messages to be processed
audit.process(to_audit)





import requests

class GuardianAudit:

    guardian_base_url = (
        "https://apiv1.holisticai.com/api/v1/shield-protection/audit"
    )
    prompts_endpoint = "/unauthenticated/prompts"
    run_audit_endpoint = "/unauthenticated/run-audit"


    def __init__(self, config):
        self.config = config
        self.validate_config(config)

    @staticmethod
    def validate_config(config):
        if "apikey" not in config:
            raise Exception("Expected apikey does not exist in the provided config")
        if "audit_id" not in config:
            raise Exception("Expected api name does not exist in the provided config")

    # hardcoded only for stereotype prompts
    def load_prompts(self):
        url = self.guardian_base_url + self.prompts_endpoint + f"/{self.config['tenant_id']}/{self.config['audit_id']}"
        headers = {
            "x-hai-guardian-key": self.config["apikey"],
            "apikey": "918vz18ncjupyl4wl8ocxhanrzy2gvr51b9qo98pk",
        }
        response = requests.get(url=url, headers=headers)
        return response.json()

    def process(self, data):
        url = self.guardian_base_url + self.run_audit_endpoint
        headers = {
            "x-hai-guardian-key": self.config["apikey"],
            "apikey": "918vz18ncjupyl4wl8ocxhanrzy2gvr51b9qo98pk",
        }
        json_data = {
            "tenant_id": self.config["tenant_id"],
            "audit_id": self.config["audit_id"],
            "apikey": self.config["apikey"],
            "messages": data
        }
        response = requests.post(url=url, headers=headers, json=json_data)
        print(response)



import openai
from openai import Completion

class GPTWrapper:

    def __init__(self):
        self.model = "gpt-3.5-turbo-instruct"
        openai.api_key = "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"

    def complete(self, prompt
                 ):
        return Completion.create(
            model=self.model,
            prompt=prompt,
            stop = ["."]
        )